Documentation
¶
Index ¶
- type Attachment
- type Client
- func (c *Client) AddAttachment(issueKey, filePath string, filename string) ([]Attachment, error)
- func (c *Client) AddComment(issueKey string, adfBody map[string]interface{}) (*Comment, error)
- func (c *Client) AddCommentWiki(issueKey string, wikiBody string) (*Comment, error)
- func (c *Client) BaseURL() string
- func (c *Client) CreateIssue(projectKey, summary, issueType string, description map[string]interface{}, ...) (*Issue, error)
- func (c *Client) CreateIssueLink(linkTypeName, inwardIssueKey, outwardIssueKey string) error
- func (c *Client) CreateIssueWiki(projectKey, summary, issueType string, description string, ...) (*Issue, error)
- func (c *Client) DeleteComment(issueKey, commentID string) error
- func (c *Client) DeleteIssue(issueKey string, deleteSubtasks bool) error
- func (c *Client) DeleteIssueLink(linkID string) error
- func (c *Client) GetAssignableUsers(projectKey string, maxResults int) ([]User, error)
- func (c *Client) GetComments(issueKey string, maxResults int) (*CommentPage, error)
- func (c *Client) GetIssue(issueKey string, fields []string, expand []string) (*Issue, error)
- func (c *Client) GetIssueLinkTypes() ([]IssueLinkType, error)
- func (c *Client) GetIssueLinks(issueKey string) ([]IssueLink, error)
- func (c *Client) GetIssueTypes() ([]IssueType, error)
- func (c *Client) GetMyself() (*User, error)
- func (c *Client) GetPriorities() ([]Priority, error)
- func (c *Client) GetProject(projectKey string) (map[string]interface{}, error)
- func (c *Client) GetProjects(maxResults int) ([]Project, error)
- func (c *Client) GetStatuses(projectKey string) ([]map[string]interface{}, error)
- func (c *Client) GetTransitions(issueKey string) ([]Transition, error)
- func (c *Client) SearchIssues(jql string, fields []string, maxResults int, nextPageToken string) (*SearchResult, error)
- func (c *Client) SearchUsers(query string, maxResults int) ([]User, error)
- func (c *Client) TransitionIssue(issueKey, transitionID string) error
- func (c *Client) UpdateComment(issueKey, commentID string, adfBody map[string]interface{}) (*Comment, error)
- func (c *Client) UpdateCommentWiki(issueKey, commentID string, wikiBody string) (*Comment, error)
- func (c *Client) UpdateIssue(issueKey string, fields map[string]interface{}) error
- func (c *Client) UpdateIssueWiki(issueKey string, fields map[string]interface{}) error
- type Comment
- type CommentPage
- type Issue
- type IssueFields
- type IssueLink
- type IssueLinkType
- type IssueType
- type Priority
- type Project
- type SearchResult
- type Status
- type Transition
- type User
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Attachment ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func (*Client) AddAttachment ¶
func (c *Client) AddAttachment(issueKey, filePath string, filename string) ([]Attachment, error)
func (*Client) AddComment ¶
func (*Client) AddCommentWiki ¶
AddCommentWiki adds a comment using the v2 REST API, which accepts wiki markup as a plain string body. This is needed for inline image support (!filename!).
func (*Client) CreateIssue ¶
func (*Client) CreateIssueLink ¶
func (*Client) CreateIssueWiki ¶
func (c *Client) CreateIssueWiki(projectKey, summary, issueType string, description string, priority, assignee string, labels []string, dueDate, parentKey string) (*Issue, error)
CreateIssueWiki creates an issue using the v2 REST API, which accepts wiki markup for text fields like description. This is needed for inline image support (!filename!).
func (*Client) DeleteComment ¶
func (*Client) DeleteIssue ¶
func (*Client) DeleteIssueLink ¶
func (*Client) GetAssignableUsers ¶
func (*Client) GetComments ¶
func (c *Client) GetComments(issueKey string, maxResults int) (*CommentPage, error)
func (*Client) GetIssueLinkTypes ¶
func (c *Client) GetIssueLinkTypes() ([]IssueLinkType, error)
func (*Client) GetIssueTypes ¶
func (*Client) GetPriorities ¶
func (*Client) GetProject ¶
func (*Client) GetStatuses ¶
func (*Client) GetTransitions ¶
func (c *Client) GetTransitions(issueKey string) ([]Transition, error)
func (*Client) SearchIssues ¶
func (*Client) SearchUsers ¶
func (*Client) TransitionIssue ¶
func (*Client) UpdateComment ¶
func (*Client) UpdateCommentWiki ¶
UpdateCommentWiki updates a comment using the v2 REST API, which accepts wiki markup as a plain string body. This is needed for inline image support (!filename!).
func (*Client) UpdateIssue ¶
type CommentPage ¶
type Issue ¶
type Issue struct {
ID string `json:"id"`
Key string `json:"key"`
Self string `json:"self"`
Fields IssueFields `json:"fields"`
}
type IssueFields ¶
type IssueFields struct {
Summary string `json:"summary"`
Description map[string]interface{} `json:"description,omitempty"`
Status *Status `json:"status,omitempty"`
Priority *Priority `json:"priority,omitempty"`
IssueType *IssueType `json:"issuetype,omitempty"`
Assignee *User `json:"assignee,omitempty"`
Reporter *User `json:"reporter,omitempty"`
Created string `json:"created,omitempty"`
Updated string `json:"updated,omitempty"`
DueDate string `json:"duedate,omitempty"`
Labels []string `json:"labels,omitempty"`
Project *Project `json:"project,omitempty"`
Comment *CommentPage `json:"comment,omitempty"`
Parent *Issue `json:"parent,omitempty"`
}
type IssueLink ¶
type IssueLink struct {
ID string `json:"id"`
Type *IssueLinkType `json:"type,omitempty"`
InwardIssue *Issue `json:"inwardIssue,omitempty"`
OutwardIssue *Issue `json:"outwardIssue,omitempty"`
}
type IssueLinkType ¶
type SearchResult ¶
type Transition ¶
Click to show internal directories.
Click to hide internal directories.